@@ -10,19 +10,19 @@ import numpy as np
 import ROOT
 
 class ExtendedMinimizer(object):
-    _SCAN_EXCLUDE_CONFIG_ = ['scan', 'Minos', 'save']
+    _SCAN_EXCLUDE_CONFIG_ = ['scan', 'minos', 'save']
     _NLL_COMMANDS_ = ['NumCPU', 'Constrain', 'CloneData', 'GlobalObservables', 
                       'GlobalObservablesTag', 'OffsetLikelihood', 'Offset']
 
     _DEFAULT_MINIMIZER_CONFIG_ = {
         'minimizer_type': 'Minuit2',
         'minimizer_algo': 'Migrad',        
-        'opt_const': 2,
+        'opt_const': 1,
         'verbose': 0,
         'save': 0,
         'timer': 1,
-        'Hesse': 0,
-        'Minos': 0,
+        'hesse': 0,
+        'minos': 0,
         'scan': 0,
         'num_ee': 5,
         'do_ee_wall': 1,
@@ -48,7 +48,9 @@ class ExtendedMinimizer(object):
         self.name = minimizer_name
         self.pdf = pdf
         self.data = data
+        self.minimizer = None
         self.nll = None
+        self.fit_result = None
         
         self._config = self._DEFAULT_MINIMIZER_CONFIG_   
         self.minos_set = ROOT.RooArgSet()
@@ -110,16 +112,20 @@ class ExtendedMinimizer(object):
                                                   self.config['print_level'])
         return None
     
-    def create_nll(self):
+    def create_nll(self, nll_command_list:List["ROOT.RooCmdArg"]=None):
         if (not self.nll) or (not self.config['reuse_nll']):
-            self.nll = self.pdf.createNLL(self.data, self.nll_command_list)
+            if nll_command_list is None:
+                nll_command_list = self.nll_command_list
+            else:
+                nll_command_list = self.parse_nll_commands(nll_command_list)
+            self.nll = self.pdf.createNLL(self.data, nll_command_list)
         
     def create_minimizer(self):
         
         if not self.nll:
             raise RuntimeError('NLL not initialized')
-            
-        if not self.config['reuse_minimizer']:
+
+        if (self.minimizer is None) or (not self.config['reuse_minimizer']):
             self.configure_default_minimizer_options()            
             self.minimizer = ROOT.RooMinimizer(self.nll)
             self.minimizer.setPrintLevel(self.config['print_level'])
@@ -135,12 +141,12 @@ class ExtendedMinimizer(object):
                 self.minimizer.setMaxFunctionCalls(self.config['max_calls'])
             if self.config['max_iters'] != -1:
                 self.minimizer.setMaxIterations(self.config['max_iters'])
-    
+ 
     def parse_nll_commands(self, commands:List["ROOT.RooCmdArg"]):
         nll_command_list = ROOT.RooLinkedList()
         for command in commands:
             nll_command_list.Add(command)
-        self.nll_command_list = nll_command_list
+        return nll_command_list
     
     def configure(self, **kwargs):
         minos_set = kwargs.pop('minos_set', None)
@@ -155,7 +161,7 @@ class ExtendedMinimizer(object):
         # parse nll commands 
         nll_commands = kwargs.pop('nll_commands', [])
         if nll_commands:
-            self.parse_nll_commands(nll_commands)
+            self.nll_command_list = self.parse_nll_commands(nll_commands)
         
         # configure minimizer settings
         for arg in kwargs:
@@ -167,7 +173,7 @@ class ExtendedMinimizer(object):
         self.scan_options = {k:v for k,v in kwargs.items() if k not in self._SCAN_EXCLUDE_CONFIG_}
 
     def minimize(self, **kwargs):
-        
+
         self.configure(**kwargs)
         self.create_nll()
         
@@ -191,7 +197,7 @@ class ExtendedMinimizer(object):
             status = self.robust_minimize()
         
         # Evaluate errors with Hesse
-        if self.config['Hesse']:
+        if self.config['hesse']:
             self.minimizer.hesse()
         
         # Obtain Hessian matrix either from patched Minuit or after inversion
@@ -203,7 +209,7 @@ class ExtendedMinimizer(object):
             self.eigen_analysis()
         
         # Evaluate errors with Minos
-        if self.config['Minos']:
+        if self.config['minos']:
             if self.minos_set.size() > 0:
                 self.minimizer.minos(self.minos_set)
             else:
@@ -220,6 +226,8 @@ class ExtendedMinimizer(object):
             save_title = "Result of fit of p.d.f. {} to dataset {}".format(self.name, data_name)
             print('INFO: ExtendedMinimizer::minimize("{}") saving results as {}'.format(self.name, save_name))
             self.fit_result = self.minimizer.save(save_name, save_title)
+        else:
+            self.fit_result = self.minimizer.save()
 
         if self.cond_set.size() > 0:
             attached_set = self.nll.getVariables()
